################################################################################
# Licensed Materials - Property of IBM Copyright IBM Corporation 2012. All Rights Reserved.
# U.S. Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP
# Schedule Contract with IBM Corp.
################################################################################
# Defines a new ScriptPackage on Workload Deployer.
#
# This script is called as follows:
#
# deployer <deployer_options> -f createScriptPackage.py
#     [-n|--name <name>] [-f|--file <path/to/file.zip>] [-r|--replace]
#
# Where:
#
# -n|--name <name>
#     specifies the name for the Script Package on Workload Deployer
#
# -f|--file <path>
#     specifies the path to the archive file to be uploaded on Workload Deployer
#
# -r|--replace
#     specifies if existing script package is found on Workload Deployer whether
#     it should be replaced or the script should fail
#
# The user will be prompted for any values not supplied on the command
# line.

import getopt
import sys

    
# parse command line arguments
try:
    (options, args) = getopt.getopt(sys.argv[1:], 'n:f:r', ['name=', 'file=', 'replace'])
except getopt.GetoptError:
    help()

parms = {}
replace = False

for option in options:
    if option[0] == '-n' or option[0] == '--name':
        parms['name'] = option[1]

    if option[0] == '-f' or option[0] == '--file':
        parms['file'] = option[1]
        
    if option[0] == '-r' or option[0] == '--replace':
        replace = True
              
# fail if script already exists and replace = False
scripts = deployer.scripts[parms['name']]
if filter(lambda s: s.name == parms['name'], scripts):
    if not replace:
         print 'Error: a script package with the name ' + parms['name'] + ' already exists!'
         sys.exit()
    else:
        script = scripts[0]
else:
    # create script
    script = deployer.scripts << {
        'name': parms['name']
    }
    
    # make sure scripts can be read by everyone        
    user = deployer.everyone()   
    script.acl[user] = deployer.READ_PERMISSION

script.archive << parms['file']

if replace:
    print parms['name'] + ' script package updated successfully!\n'
else:
    print parms['name'] + ' script package created successfully!\n'
