require 'weaver/cli/weaver_cli_plugin'
require 'thor/actions'
require 'weaver/core/constants'

module Weaver
  module Cli
    module Plugins

      # Project plugin for the Weaver CLI
      #
      # Syntax: weaver project [task] [options]
      #
      # Author:: Florian Rosenberg
      #
      class ProjectCliPlugin <  Weaver::Cli::WeaverCliPlugin
        include Thor::Actions
        
        KNOWN_PROVIDERS = ['openstack', 'amazon_ec2', 'smartcloud', 'wcc' ]
                
        def self.source_root
          "#{ File.dirname(__FILE__)}/templates"
        end

        # Special non-Thor extension to provide help for the arguments of the commands
        ARG_DEFS = {
          'NAME' => 'The name for the new project',
        }
        
        namespace :project
        namespace_description "Project scaffolding related tasks"

        desc "create NAME", "Create a Weaver project scaffold"
        method_option :provider, :aliases => "-p", :type => :string, :required => false, :desc => "Provisioning provider (e.g., aws, openstack, smartcloud, ..)"        
        method_option :filename, :aliases => "-f", :type => :string, :required => false, :desc => "Name of the config file (default: config.yml)"
        method_option :config, :required => false, :type => :hash, :aliases => "-c", :desc => "Configuration parameters.", :default => {}
        def create(name)
          init(false)
          
          # check if provider is known
          provider = nil
          if options[:provider]
            provider = options[:provider]

            unless KNOWN_PROVIDERS.include? provider
              say_status("Error", "Unknown provider '#{provider}'. Valid providers: #{KNOWN_PROVIDERS.inspect}", :red)
              exit 1
            end
          end
          
          empty_directory name
          inside name do
            empty_directory Weaver::Core::AUTOMATION_DIR
            empty_directory Weaver::Core::TYPES_DIR
            empty_directory Weaver::Core::VALIDATORS_DIR
            empty_directory Weaver::Core::RULES_DIR
            empty_directory Weaver::Core::TOPOLOGIES_DIR
          end
         
          filename = options[:filename] || 'config.yml'
          unless filename =~ /\.yml$/
            filename += ".yml"
          end                          
          template "config.yml.erb", "#{name}/#{filename}", { :name => name, :provider => provider, :config_opts => (options[:config] || {}) }
          template "env.weaver.erb", "#{name}/#{Weaver::Core::TOPOLOGIES_DIR}/#{name}-env.weaver", 
            { :name => name, :known_providers => KNOWN_PROVIDERS, :provider => provider, :config_filename => filename }                    
          template "hidden_weaver.erb", "#{name}/.weaver", { :filename => filename } 
        end

      end
    end

  end
end
