require 'weaver/core/base'
require 'weaver/core/generation'
require 'weaver/core/automation_container'
require 'weaver/core/component_container_mixin'
require 'weaver/core/load_driver_container_mixin'
require 'weaver/core/policy_container_mixin'
require 'weaver/core/provider_container_mixin'
require 'weaver/core/service_container_mixin'

module Weaver
  module Core
    # Represents a component, such as a software installation on a Node or some configuration parameters on another Component
    # @see ComponentStatement
    #
    # Author:: Ed Snible
    # Author:: Florian Rosenberg
    class Component < Base
      include Weaver::Core::Generation
      include LoadDriverContainerMixin
      include ServiceContainerMixin
      include PolicyContainerMixin
      include AutomationContainer
      include ComponentContainerMixin
      include ProviderContainerMixin

      # Array of requirements for deploying Component successfully
      attr_accessor :requirements
      
      # * +id+ Symbol to represent the entity
      # * +parent+ The enclosing Base
      def initialize(id, parent)
        super(id, parent)
        @type = :component
        @requirements = []
                
        amd[:version] = Attribute.new(:version, self, true)
        amd[:version].implicit = true
        amd[:version].required = false  
      end

      def initialize_copy(other)
        super
        
        @requirements = []
        other.requirements.each do |requirement|
          dup = requirement.clone()
          dup.scope = self
          @requirements.push(dup)
        end
        
#        @scripts = []
#        other.scripts.each do |script|
#          dup = script.clone()
#          dup.scope = self
#          @scripts.push(dup)
#        end
      end
      
      # Validates the entity and its direct and indirect contained children.
      # * +out_messages+ ProblemStatus will be pushed onto this for any validation message
      # * +desired_phases+ optional Array which may be +[:predefined]:
      def validate_collect(out_messages, desired_phases = nil)
#        puts "component.validate_collect"
        @@logger.debug "Validating component '#{id}'"
        @@logger.debug "  has type '#{type}'"
        @@logger.debug "  has name '#{name}'"
        @@logger.debug "  has description '#{description}'"
#        @@logger.debug "  has #{scripts.size} scripts"
        @@logger.debug "  has #{load_drivers.size} load_drivers"
        @@logger.debug "  has #{policies.size} polic(y/ies)"
#        scripts.each { |script|
#          script.validate_collect(out_messages);
#        }

        super
        
#        # Validate child components
#        components.each do |id, child|
#          child.validate_collect(out_messages)
#        end

        # Currently these are validated in isolation.
        # TODO validate correctly, so if two Nodes with requirement for port 8080 are realized
        # upon the same infrastructure a message is generated here
        requirements.each do |requirement|
          requirement.validate_collect(out_messages, desired_phases)
        end
#        policies.each { |id, policy| policies.validate_collect(out_messages) }
        validate_policies(out_messages, desired_phases);
      end

      # Returns true if this Component is equal to another Component
      def ==(other)
        retval = super
        return retval && @components == other.components && @requirements == other.requirements
#          @scripts == other.scripts 
      end
      
    end
  end
end