require 'net/ssh'
require 'rubygems'
require 'socket'

require 'weaver/core/base.rb'

module Weaver
  module Core
  
    # A policy class that specifies which resources should be monitored and
    # how they should be monitored.
    #
    # Author:: Thomas Gschwind <thg@zurich.ibm.com>
    # Copyright:: IBM
    class Policy < Base
      include ImportContainerMixin

      attr_accessor :asserts
      
      # Create a Policy
      def initialize(id, weaver_parser)
        super(id, weaver_parser)
        @type = :policy
        @asserts = []
      end

      # @see Base#validate_collect      
      def validate_collect(out_messages, desired_phases = nil)
        @@logger.debug "Validating policy '#{id}'"
        super
      end

      # Enable or disable a policy (connects to the policy's node and tell
      # the service to start/stop this policy).
      def service(cmd)
        node = nil
        current = self.scope
        while current != nil do
          if current.kind_of? Node
            node = current
          end
          current = current.scope
        end
        
#        puts "node = #{node}, password = #{node.root_pwd}"
        hostname = node.hostname
        username = 'root'
        root_pwd = node.root_pwd
        root_pwd = Weaver::Utils::ValueDecryptor.decrypt_if_needed("root_pwd", root_pwd.ciphertext) if root_pwd.respond_to?(:ciphertext)        
#        root_pwd = Weaver::Utils::ValueDecryptor.decrypt_if_needed("root_pwd", root_pwd)
        
        ssh_result = nil
        unless hostname.nil?
#          puts "service #{self.type}"
          if  self.type == :itm_policy
            ssh_command = "service #{self.type} -s -u '#{self.username}' -p '#{self.password}' #{cmd} #{id}"
          else
            ssh_command = "service #{self.type} -s #{cmd} #{id}"
          end
#          puts "pol: root%#{password}@#{hostname}: #{ssh_command}"
          Net::SSH.start(hostname, username, :password => password, :paranoid => false) do |ssh|
            ssh_result = ssh.exec! "#{ssh_command}"
          end
        else
          puts "Hostname not set"
        end # hostname.nil?
        
        return ssh_result
      end

    end
  end
end
