require 'weaver/core/status_constants'

module Weaver
  module Core
    # Represents a resolution that is proposed to resolve an issue captured by a Rule
    # @see ResolutionStatement
    #
    # Copyright:: IBM
    class Resolution

      # The label of the resolution (String)
      attr_accessor :label

      # The description of the resolution (String), optional additional information, for example info that may be presented to assist the user in deciding if this resolution is the desired choice.
      attr_accessor :description

      # The type of the resolution (String); the type may be used by the UI to choose an image that will indicate the type of action that will be performed by the resolution, such as a model update
      attr_accessor :type

      # The process to run to perform a fix
      attr_accessor :fix_proc
      
      def initialize(label=nil, description=nil, type = Weaver::Core::ResolutionTypes::DEFAULT, fix_proc = nil)
        @label = label
        @description = description
        @type = type || Weaver::Core::ResolutionTypes::DEFAULT
        @fix_proc = fix_proc
      end

      # Summarize
      def to_s
        str = "#{label}" 
        str = "#{label}; #{description}" unless description.nil? || description.size == 0
        str
      end


    end
  end
end