
module Weaver
  module Deployers
    
    # This class helps Service execute pre/post deployment and undeploy blocks during Weaver deploy  
    class ServiceSandbox
      # * +service+ Service containing the operation
      # * +op+ String representing the operation being sandboxed, e.g. 'predeploy'
      # * +flow_model+ Hash, representing dataflow
      def initialize(service, op, flow_model)
        @service = service
        @op = op
        @output_attributes = flow_model[:outputs] || {}
        @input_attributes = flow_model[:inputs] || {}
      end
      
      def method_missing(sym, *args, &block)
        if sym.to_s[-1,1] == '='        
          # We are being asked to set, do we have an attribute by that name?
          output_sym = sym.to_s.chop.to_sym                
          if @service.amd.key?(output_sym)
            if @output_attributes.member?(output_sym)
              @service.amd[output_sym].value = args[0]
              return args[0]
            end
            raise WeaverError.new("Forbidden output in #{@service.fully_qualified_id}: #{output_sym} cannot be set in Service.#{@op}")
          end
        elsif @service.amd.key?(sym)
          # We are being asked to read 
          if @input_attributes.member?(sym)
            return @service.amd[sym].value
          end
          raise WeaverError.new("Forbidden input in #{@service.fully_qualified_id}: #{sym} cannot be accessed in Service.#{@op}")
        end
                  
        raise WeaverError.new("Forbidden operation #{sym} in Service.#{@op}")
      end
    end
  end
end