require 'weaver/core/logging'
require 'weaver/core/service'

module Weaver
  module Dsl
    # Mix in ServiceContainerStatement with statements that may contain {ServiceStatement}
    #
    # Author:: Ed Snible
    # Copyright:: IBM
    module ServiceContainerStatement
      include Weaver::Core
      
      # * *Args* :
      #   -+base+ the AbstractStatement being mixed with
      def self.included(base)
        base.register_statement_handler([:service_handler])
      end
      
      # * *Args* :
      #   -+sym_or_model+ <Symbol representing Weaver type, e.g. <code>:node</code> | Core::Node
      #   -+id+ Symbol naming entity
      #   -+block+ optional block of additional metadata
      def service_handler(sym_or_model, id, &block)
        return nil unless is_a?(Weaver::Dsl::ServiceContainerStatement) && (sym_or_model.kind_of?(Weaver::Core::Service) || root_statement.model.weaver_extended_type?(sym_or_model, Weaver::Core::Service))
        return nil unless id.kind_of?(Symbol) 
        
        prototype = sym_or_model.kind_of?(Symbol) ? root_statement.model.prototype_instance(sym_or_model, id, model, weaver_stackframe) : sym_or_model 
        service(id, prototype, &block)
      end
      
      # Create and optionally parse Service
      #   - +id_or_model+ ServiceStatement | Symbol naming new Service
      #   - +block+ optional block of additional Service metadata
      def service(id, prototype = nil, &block)
        @@logger.debug "service[(#{prototype.nil? ? 'service' : prototype.type}): #{id}]"
         
         return if fail_id_redefinition(id, Service)
         
         service_model = @model.services[id]
         if service_model.nil?
           service_model = prototype || root_statement.model.prototype_instance(:service, id, model, weaver_stackframe)
           @model.services[id] = service_model
         else
           root_statement.model.widen(service_model, prototype) unless prototype.nil?
         end
         
         unless block.nil?
           service = ServiceStatement.new(service_model, self)
           
           begin
             service.instance_eval &block
           rescue ArgumentError => ae
             # For example the statement 'component' without an ID yields
             # 'wrong number of arguments (0 for 1)'
             service_model.add_validation_failure(" #{ae.message}", weaver_stackframe(ae.backtrace))
             @@logger.warn "Caught #{ae.inspect} processing 'service' statement, backtrace=#{ae.backtrace}"
           rescue NameError => ne
             # For example the statement 'N1.name' yields NameError uninitialized constant
             service_model.add_validation_failure(" #{ne.message}", weaver_stackframe(ne.backtrace))
             @@logger.warn "Caught #{ne.inspect} processing 'service' statement, backtrace=#{ne.backtrace}"
           end
         end
 
         return service_model
      end
      
    end

  end

end