require "logger"    # Ruby Logging

module Weaver
  # @see Weaver::Iwd
  module IWDUtils
    
      # @private
      MESSAGES = {
        :props_file_does_not_exist => {:label => "IBM Workload Deployer credentials cannot be read from the properties file. The environment variable '%s' points to a properties file, '%s', but the file does not exist.", :severity => Logger::WARN, :predeployment_severity => Logger::WARN},
        :set_props_file_var => {:label => "Set the environment variable '%s' to point to a properties file that specifies the following IBM Workload Deployer properties: ['iwd_properties']['hostname'], ['iwd_properties']['user'] and ['iwd_properties']['password'].", :severity => Logger::WARN, :predeployment_severity => Logger::WARN},
        :error_loading_yml_file => {:label => "IBM Workload Deployer credentials cannot be read from properties file '%s.' The exception is '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::WARN},
        :invalid_credentials => {:label => "Invalid credentials for IBM Workload Deployer connection: attempted to connect to hostname '%s', user '%s', password '%s', ssl_verify_cert = '%s', using environment variable 'PROPS_FILE' set to '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::ERROR},
        :set_weaver_system_properties => {:label => "Set the IBM Workload Deployer credentials in the Weaver system properties: 'iwd.hostname', 'iwd.user', 'iwd.password' and 'iwd.use_ssl' (optional).", :severity => Logger::INFO, :predeployment_severity => Logger::INFO},
        :set_env_var_props_file => {:label => "Set the environment variable 'PROPS_FILE' to the location of a .yml file that has IBM Workload Deployer credentials defined under 'iwd_properties' with the following property names: 'hostname', 'user', 'password', 'ssl_verify_cert' (optional).", :severity => Logger::INFO, :predeployment_severity => Logger::INFO}, 
        :invalid_pattern => {:label => "User cannot access pattern '%s' with id '%s' at '%s' as user '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::ERROR},
        :unauthorized_access => {:label => "Unauthorized access to '%s' for user '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::ERROR},
        :generate_pattern_error => { :label => "Error generating pattern '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::WARN},
        :part_not_on_server => { :label =>"A part has been deleted from the pattern on the server: pattern id '%s', part '%s', id '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::WARN},
        :part_added_to_server => { :label =>"A part has been added to the pattern on the server: pattern id '%s', part '%s', id '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::WARN},
        :pattern_property_not_on_server => { :label =>"A pattern property is not on the server: property '%s', id '%s', pattern id '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::WARN},
        :required_pattern_property_added_to_server => { :label =>"A required pattern property has been added to the server: property '%s', id '%s', pattern id '%s.'", :severity => Logger::ERROR, :predeployment_severity => Logger::ERROR},
        :pattern_property_added_to_server => { :label =>"A pattern property has been added to the server: property '%s', id '%s', pattern id '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::WARN},
        :part_property_not_on_server => { :label =>"A part property is not on the server: property '%s', id '%s', part id '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::WARN},
        :required_part_property_added_to_server => { :label =>"A required part property has been added to the server: property '%s', id '%s', part id '%s.'", :severity => Logger::ERROR, :predeployment_severity => Logger::ERROR},
        :part_property_added_to_server => { :label =>"A part property has been added to the server: property '%s', id '%s', part id '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::WARN},
        :script_package_not_in_part => { :label =>"A script package has been removed from a part on the server: script package '%s', id '%s', part '%s', id '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::WARN},
        :script_package_added_to_part => { :label =>"A script package has been added to a part on the server: script package '%s', id '%s', part '%s', id '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::WARN},
        :script_package_property_not_on_server => { :label =>"A script package parameter is not on the server: property '%s', id '%s', script package id '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::WARN},
        :required_script_package_property_added_to_server => { :label =>"A required script package parameter has been added to the server: property '%s', id '%s', script package id '%s.'", :severity => Logger::ERROR, :predeployment_severity => Logger::ERROR},
        :script_package_property_added_to_server => { :label =>"A script package parameter has been added to the server: property '%s', id '%s', script package id '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::WARN},
        :part_id_to_image_id_changed => { :label =>"The metadata that describes a part within the pattern has changed: part '%s', description '%s', part resource id '%s', part id '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::WARN},
        :script_id_to_global_id_changed => { :label =>"The metadata that describes a script within the pattern has changed: script '%s', description '%s', global script id '%s.'", :severity => Logger::WARN, :predeployment_severity => Logger::WARN},      
        :reimport_pattern => { :label =>"Import pattern '%s' with id '%s'%s again.", :severity => Logger::INFO, :predeployment_severity => Logger::INFO},
        :change_credentials => { :label =>"Change the user and password credentials for the connection to IBM Workload Deployer at '%s.'", :severity => Logger::INFO, :predeployment_severity => Logger::INFO},
        :import_another_pattern => { :label =>"Import a different pattern and use it in the topology instead of pattern '%s' with id '%s.'", :severity => Logger::INFO, :predeployment_severity => Logger::INFO}     
      }
      
      # @private
      REGEXPS = {
        :props_file_does_not_exist => /IBM Workload Deployer credentials cannot be read from the properties file.*/,
        :set_props_file_var => /Set the environment variable.*/,
        :error_loading_yml_file => /IBM Workload Deployer credentials cannot be read.*/,
        :invalid_credentials => /Invalid credentials for IBM Workload Deployer connection.*/,
        :set_weaver_system_properties => /Set the IBM Workload Deployer credentials in the Weaver system properties.*/,
        :set_env_var_props_file => /Set the environment variable.*/,
        :invalid_pattern => /User cannot access pattern.*/,
        :unauthorized_access => /Unauthorized access.*/,
        :generate_pattern_error => /Error generating pattern.*/,
        :part_not_on_server => /A part has been deleted from the pattern on the server.*/,
        :part_added_to_server => /A part has been added to the pattern on the server.*/,
        :pattern_property_not_on_server => /A pattern property is not on the server.*/,
        :required_pattern_property_added_to_server => /A required pattern property has been added to the server.*/,
        :pattern_property_added_to_server => /A pattern property has been added to the server.*/,
        :part_property_not_on_server => /A part property is not on the server.*/,
        :required_part_property_added_to_server => /A required part property has been added to the server.*/,
        :part_property_added_to_server => /A part property has been added to the server.*/,
        :script_package_not_in_part => /A script package has been removed from a part on the server.*/,
        :script_package_added_to_part => /A script package has been added to a part on the server.*/,
        :script_package_property_not_on_server => /A script package parameter is not on the server.*/,
        :required_script_package_property_added_to_server => /A required script package parameter has been added to the server: property.*/,
        :script_package_property_added_to_server => /A script package parameter has been added to the server.*/,
        :part_id_to_image_id_changed => / The metadata that describes a part within the pattern has changed.*/,
        :script_id_to_global_id_changed => / The metadata that describes a script within the pattern has changed.*/,
        :reimport_pattern => /Import pattern.*/,
        :change_credentials => /Change the user and password.*/,
        :import_another_pattern => /Import a different pattern.*/
     }
     
     # @private
     RESOLUTION_LABELS = {
       :reimport_pattern => "Import the IBM Workload Deployer pattern again.",
       :change_credentials => "Change the IBM Workload Deployer credentials.",
       :import_another_pattern => "Import a different pattern.",
       :set_props_file_var => "Use a properties file to specify the credentials.",
       :set_weaver_system_properties => "Set the IBM Workload Deployer credentials in the Weaver system properties.",
       :set_env_var_props_file => "Set the IBM Workload Deployer credentials in a properties file."
     }

        
  end
end