require 'weaver/core/base.rb'
require 'weaver/validation/problem_status'

module Weaver
  module Providers
    # Base class for providers
    #
    # Author:: Ed Snible
    # Copyright:: IBM
    class ProviderImpl
      
      def initialize(provider)
        @provider_model = provider
      end
      
      def deploy(topology, deploy_parameters = {})
        raise WeaverError.new("#{self.class}.deploy() unimplemented")
      end
      
      def simulate_deploy(topology, deploy_parameters = {})
        raise WeaverError.new("#{self.class}.simulate_deploy() unimplemented")
      end
      
      # Validates that +entity+ can be published by this provider.  An example
      # is that for example only some providers handle elastic_ip
      # * +out_messages+ ProblemStatus will be pushed onto this for any validation message
      # * +desired_phases+ optional Array which may be +[:predefined]:
      def validate_publishability(entity, out_messages, desired_phases)
        out_messages.push Weaver::Validation::ProblemStatus.new(Logger::ERROR, "Cannot be published by #{@provider_model.fully_qualified_id}", entity)
      end
      
    end
  end
end